@@ -25,9 +25,7 @@ if platform.system() == "Windows":
     import winsound
     # For SAPI speech
     from comtypes.client import CreateObject
-    sapivoice = CreateObject("SAPI.SpVoice")
-    sapistream = CreateObject("SAPI.SpFileStream")
-    from comtypes.gen import SpeechLib
+
 if platform.system() == "Darwin":
     from playsound import playsound
 if platform.system() == "Linux":
@@ -86,7 +84,7 @@ phraseList = []
 port = ""
 
 # define library version
-version = "1.255"
+version = "1.257"
 
 # flag to stop writing when writing for threading
 writing = False
@@ -348,39 +346,43 @@ def _parseSAPIVoice(flag):
 
 # generate speech file depending on platform and sythensizer.
 def _generateSpeechFile(text):
-    # Pick up the global variable that defines the language. This is only used in GTTS speech.
+    # Pick up the global variable that defines the language. This is only used in GTTS speech.
     global language
     file = speechAudioFile
     if platform.system() == "Windows":
         if ("sapi" in synthesizer.lower()):
-            #from comtypes.gen import SpeechLib
+            from comtypes.gen import SpeechLib
             global sapivoice, sapistream
+            #sapivoice = CreateObject("SAPI.SpVoice")
+            #sapistream = CreateObject("SAPI.SpFileStream")
+            try:
+                sapistream.Open(file, SpeechLib.SSFMCreateForWrite)
+                sapivoice.AudioOutputStream = sapistream
 
-            sapistream.Open(file, SpeechLib.SSFMCreateForWrite)
-            sapivoice.AudioOutputStream = sapistream
+                # set any parameters
+                sa = _parseSAPIVoice("a");
+                if _is_digit(sa):
+                    sapivoice.Volume = int(sa)
+                else:
+                    sapivoice.Volume = 100
+                sr = _parseSAPIVoice("r")
+                if _is_digit(sr):
+                    sapivoice.Rate = int(sr)
+                else:
+                    sapivoice.Rate = 0
+                sv = _parseSAPIVoice("v");
+                # Default voice is always first in the list
+                if (sv == ''):
+                    sapivoice.voice = sapivoice.GetVoices()[0]
+                else:
+                    for v in sapivoice.GetVoices():
+                        if (sv.lower() in v.GetDescription().lower()):
+                            sapivoice.voice = v
 
-            # set any parameters
-            sa = _parseSAPIVoice("a");
-            if _is_digit(sa):
-                sapivoice.Volume = int(sa)
-            else:
-                sapivoice.Volume = 100
-            sr = _parseSAPIVoice("r")
-            if _is_digit(sr):
-                sapivoice.Rate = int(sr)
-            else:
-                sapivoice.Rate = 0
-            sv = _parseSAPIVoice("v");
-            # Default voice is always first in the list
-            if (sv == ''):
-                sapivoice.voice = sapivoice.GetVoices()[0]
-            else:
-                for v in sapivoice.GetVoices():
-                    if (sv.lower() in v.GetDescription().lower()):
-                        sapivoice.voice = v
-
-            sapivoice.Speak(text)
-            sapistream.Close()
+                sapivoice.Speak(text)
+                sapistream.Close()
+            except:
+                print("Speech being generated too quickly")
         else:
             # Remove any characters that are unsafe for a subprocess call
             safetext = re.sub(r'[^ .a-zA-Z0-9?\']+', '', text)
@@ -453,6 +455,8 @@ def init(portName):
 
     # get the sapi objects ready on Windows
     if platform.system() == "Windows":
+        sapivoice = CreateObject("SAPI.SpVoice")
+        sapistream = CreateObject("SAPI.SpFileStream") 
         winsound.PlaySound(silenceFile, winsound.SND_FILENAME)
 
     # get the audio system warmed up on Mac
@@ -735,7 +739,7 @@ def say(text, untilDone=True, lipSync=True, hdmiAudio=False, soundDelay=0):
 
         # How many samples per second for mouth position
         if platform.system() == "Windows":
-            VISEMESPERSEC = 10
+            VISEMESPERSEC = 20
         if platform.system() == "Darwin":
             VISEMESPERSEC = 10
         if platform.system() == "Linux":
@@ -853,10 +857,9 @@ def _moveSpeech(phonemes, times):
                     #posTop = _phonememapTopFest(phonemes[x])
                     posBottom = _phonememapBottomFest(phonemes[x])
                 else:
-                    posTop = _phonememapTop(phonemes[x])
+                    #posTop = _phonememapTop(phonemes[x])
                     posBottom = _phonememapBottom(phonemes[x])
                 # move(TOPLIP, posTop, 10)
-                posBottom = (((posBottom-5)/5)*3)+5
                 move(BOTTOMLIP, posBottom, 10)
                 currentX = x
     # move(TOPLIP, 5)
